@@ -1,14 +1,16 @@
 import subprocess,json,socket,time
 
+
 class WebBotMain:
     wait_timeout = 3  # seconds
     interval_timeout = 0.5  # seconds
-
+    socket.setdefaulttimeout(5)
     def __init__(self,port):
         self.port = port
         address_info = socket.getaddrinfo("127.0.0.1", port, socket.AF_INET, socket.SOCK_STREAM)[0]
         family, socket_type, proto, _, socket_address = address_info
         self.__sock = socket.socket(family, socket_type, proto)
+        socket.setdefaulttimeout(10)
         time.sleep(2)
         while True:
             try:
@@ -138,6 +140,7 @@ class WebBotMain:
     def closePage(self) -> bool:
         """
         关闭当前页面
+        谷歌浏览器关闭页面有bug
         """
         result = self.__send_data("closePage")
         return result == "true"
